==> Botania-r1.10-359.11-sources.jar: vazkii/botania/client/lib/LibResources.java <==
/**
 * This class was created by <Vazkii>. It's distributed as
 * part of the Botania Mod. Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 *
 * File Created @ [Jan 14, 2014, 5:29:31 PM (GMT)]
 */
package vazkii.botania.client.lib;

import vazkii.botania.common.lib.LibMisc;

public final class LibResources {

	public static final String PREFIX_MOD = LibMisc.MOD_ID + ":";

	public static final String PREFIX_LANG = "/assets/botania/lang/";
	public static final String PREFIX_SHADER = "/assets/botania/shader/";

	public static final String PREFIX_GUI = PREFIX_MOD + "textures/gui/";
	public static final String PREFIX_ENTRIES = PREFIX_GUI + "entries/";
	public static final String PREFIX_MODEL = PREFIX_MOD + "textures/model/";
	public static final String PREFIX_MISC = PREFIX_MOD + "textures/misc/";
	public static final String PREFIX_OBJ_MODEL = PREFIX_MOD + "model/";
	public static final String PREFIX_CATEGORIES = PREFIX_GUI + "categories/";

	public static final String EMTPY_TEXTURE = "emptyTexture";

	public static final String GUI_MANA_HUD = PREFIX_GUI + "manaHud.png";
	public static final String GUI_LEXICON = PREFIX_GUI + "lexicon.png";
	public static final String GUI_PAPER = PREFIX_GUI + "paper.png";
	public static final String GUI_CRAFTING_OVERLAY = PREFIX_GUI + "craftingOverlay.png";
	public static final String GUI_MANA_INFUSION_OVERLAY = PREFIX_GUI + "manaInfusionOverlay.png";
	public static final String GUI_PURE_DAISY_OVERLAY = PREFIX_GUI + "pureDaisyOverlay.png";
	public static final String GUI_PETAL_OVERLAY = PREFIX_GUI + "petalOverlay.png";
	public static final String GUI_TERRASTEEL_OVERLAY = PREFIX_GUI + "terrasteelOverlay.png";
	public static final String GUI_ELVEN_TRADE_OVERLAY = PREFIX_GUI + "elvenTradeOverlay.png";
	public static final String GUI_SHEDDING_OVERLAY = PREFIX_GUI + "sheddingOverlay.png";
	public static final String GUI_MULTIBLOCK_OVERLAY = PREFIX_GUI + "multiblockOverlay.png";
	public static final String GUI_CREATIVE = "botania.png";
	public static final String GUI_TOFF = PREFIX_GUI + "toff.png";
	public static final String GUI_BOSS_BAR = PREFIX_GUI + "bossBar.png";
	public static final String GUI_POTIONS = PREFIX_GUI + "potions.png";
	public static final String GUI_NEI_BLANK = PREFIX_GUI + "neiBlank.png";
	public static final String GUI_NEI_BREWERY = PREFIX_GUI + "neiBrewery.png";
	public static final String GUI_FLOWER_BAG = PREFIX_GUI + "flowerBag.png";
	public static final String GUI_BAUBLE_BOX = PREFIX_GUI + "baubleBox.png";
	public static final String GUI_HUD_ICONS = PREFIX_GUI + "hudIcons.png";
	public static final String GUI_STENCIL = PREFIX_GUI + "stencil.png";
	public static final String GUI_DOG = PREFIX_GUI + "dog.png";
	public static final String GUI_FLOWEY = PREFIX_GUI + "flowey.png";

	public static final String ENTRY_FLOWERS = PREFIX_ENTRIES + "flowers.png";
	public static final String ENTRY_APOTHECARY = PREFIX_ENTRIES + "apothecary.png";
	public static final String ENTRY_PURE_DAISY = PREFIX_ENTRIES + "pureDaisy.png";
	public static final String ENTRY_SPREADER = PREFIX_ENTRIES + "spreader.png";
	public static final String ENTRY_BAUBLES = PREFIX_ENTRIES + "baubles.png";
	public static final String ENTRY_ELVEN_GARDE = PREFIX_ENTRIES + "elvenGarde.png";
	public static final String ENTRY_DIMINISHING_RETURNS = PREFIX_ENTRIES + "diminishingReturns.png";
	public static final String ENTRY_HYDROANGEAS = PREFIX_ENTRIES + "hydroangeas.png";
	public static final String ENTRY_CRAFT_CRATE = PREFIX_ENTRIES + "craftCrate.png";
	public static final String ENTRY_AZULEJOS = PREFIX_ENTRIES + "azulejos.png";
	public static final String ENTRY_METAMORPHIC_STONES = PREFIX_ENTRIES + "metamorphicStones.png";
	public static final String ENTRY_BANNERS = PREFIX_ENTRIES + "banners.png";

	public static final String MODEL_SPREADER = PREFIX_MODEL + "spreader_mana.png";
	public static final String MODEL_SPREADER_REDSTONE = PREFIX_MODEL + "spreader_redstone.png";
	public static final String MODEL_SPREADER_DREAMWOOD = PREFIX_MODEL + "spreader_dreamwood.png";
	public static final String MODEL_SPREADER_GAIA = PREFIX_MODEL + "spreader_gaia.png";
	public static final String MODEL_SPREADER_HALLOWEEN = PREFIX_MODEL + "spreader_mana_halloween.png";
	public static final String MODEL_SPREADER_REDSTONE_HALLOWEEN = PREFIX_MODEL + "spreader_redstone_halloween.png";
	public static final String MODEL_SPREADER_DREAMWOOD_HALLOWEEN = PREFIX_MODEL + "spreader_dreamwood_halloween.png";
	public static final String MODEL_SPREADER_GAIA_HALLOWEEN = PREFIX_MODEL + "spreader_gaia_halloween.png";
	public static final String MODEL_PYLON_MANA = PREFIX_MODEL + "pylon_mana.png";
	public static final String MODEL_PYLON_NATURA = PREFIX_MODEL + "pylon_natura.png";
	public static final String MODEL_PYLON_GAIA = PREFIX_MODEL + "pylon_gaia.png";
	public static final String MODEL_LEXICA_DEFAULT = PREFIX_MODEL + "lexicon_default.png";
	public static final String MODEL_LEXICA_ELVEN = PREFIX_MODEL + "lexicon_elven.png";
	public static final String MODEL_MANASTEEL_0 = PREFIX_MODEL + "manasteel_0.png";
	public static final String MODEL_MANASTEEL_1 = PREFIX_MODEL + "manasteel_1.png";
	public static final String MODEL_MANASTEEL_2 = PREFIX_MODEL + "manasteel_2.png";
	public static final String MODEL_MANASTEEL_NEW = PREFIX_MODEL + "armor_manasteel.png";
	public static final String MODEL_TERRASTEEL_0 = PREFIX_MODEL + "terrasteel_0.png";
	public static final String MODEL_TERRASTEEL_1 = PREFIX_MODEL + "terrasteel_1.png";
	public static final String MODEL_TERRASTEEL_2 = PREFIX_MODEL + "terrasteel_2.png";
	public static final String MODEL_TERRASTEEL_NEW = PREFIX_MODEL + "armor_terrasteel.png";
	public static final String MODEL_ELEMENTIUM_0 = PREFIX_MODEL + "elementium_0.png";
	public static final String MODEL_ELEMENTIUM_1 = PREFIX_MODEL + "elementium_1.png";
	public static final String MODEL_ELEMENTIUM_2 = PREFIX_MODEL + "elementium_2.png";
	public static final String MODEL_ELEMENTIUM_NEW = PREFIX_MODEL + "armor_elementium.png";
	public static final String MODEL_MANAWEAVE_0 = PREFIX_MODEL + "manaweave_0.png";
	public static final String MODEL_MANAWEAVE_1 = PREFIX_MODEL + "manaweave_1.png";
	public static final String MODEL_MANAWEAVE_NEW = PREFIX_MODEL + "armor_manaweave.png";
	public static final String MODEL_MANAWEAVE_NEW_HOLIDAY = PREFIX_MODEL + "armor_manaweave_holiday.png";
	public static final String MODEL_PIXIE = PREFIX_MODEL + "pixie.png";
	public static final String MODEL_PIXIE_HALLOWEEN = PREFIX_MODEL + "pixie_halloween.png";
	public static final String MODEL_TINY_POTATO = PREFIX_MODEL + "tiny_potato.png";
	public static final String MODEL_TINY_POTATO_GS = PREFIX_MODEL + "tiny_potato_gray.png";
	public static final String MODEL_TINY_POTATO_HALLOWEEN = PREFIX_MODEL + "tiny_potato_halloween.png";
	public static final String MODEL_TRAVEL_BELT = PREFIX_MODEL + "belt_travel.png";
	public static final String MODEL_SUPER_TRAVEL_BELT = PREFIX_MODEL + "belt_travel_super.png";
	public static final String MODEL_SPEED_UP_BELT = PREFIX_MODEL + "belt_speed.png";
	public static final String MODEL_KNOCKBACK_BELT = PREFIX_MODEL + "belt_knockback.png";
	public static final String MODEL_HOLY_CLOAK = PREFIX_MODEL + "cloak_holy.png";
	public static final String MODEL_UNHOLY_CLOAK = PREFIX_MODEL + "cloak_unholy.png";
	public static final String MODEL_BALANCE_CLOAK = PREFIX_MODEL + "cloak_balance.png";
	public static final String MODEL_HOLY_CLOAK_GLOW = PREFIX_MODEL + "cloak_holy_glow.png";
	public static final String MODEL_UNHOLY_CLOAK_GLOW = PREFIX_MODEL + "cloak_unholy_glow.png";
	public static final String MODEL_BALANCE_CLOAK_GLOW = PREFIX_MODEL + "cloak_balance_glow.png";
	public static final String MODEL_CORPOREA_INDEX = PREFIX_MODEL + "corporea_index.png";
	public static final String MODEL_INVISIBLE_ARMOR = PREFIX_MODEL + "armor_invisible.png";
	public static final String MODEL_PINK_WITHER = PREFIX_MODEL + "wither_pink.png";
	public static final String MODEL_BREWERY = PREFIX_MODEL + "brewery.png";
	public static final String MODEL_HOURGLASS = PREFIX_MODEL + "hourglass.png";
	public static final String MODEL_BELLOWS = PREFIX_MODEL + "bellows.png";
	public static final String MODEL_TERU_TERU_BOZU = PREFIX_MODEL + "teruTeruBozu.png";
	public static final String MODEL_TERU_TERU_BOZU_HALLOWEEN = PREFIX_MODEL + "teruTeruBozu_halloween.png";
	public static final String MODEL_AVATAR = PREFIX_MODEL + "avatar.png";
	public static final String MODEL_AVATAR_DIVINING = PREFIX_MODEL + "avatar_divining.png";
	public static final String MODEL_AVATAR_FIRE = PREFIX_MODEL + "avatar_fire.png";
	public static final String MODEL_AVATAR_MISSILE = PREFIX_MODEL + "avatar_missile.png";
	public static final String MODEL_AVATAR_RAINBOW = PREFIX_MODEL + "avatar_rainbow.png";
	public static final String MODEL_AVATAR_TORNADO = PREFIX_MODEL + "avatar_tornado.png";
	public static final String MODEL_AVATAR_DIRT = PREFIX_MODEL + "avatar_dirt.png";

	public static final String MISC_PARTICLES = PREFIX_MISC + "particles.png";
	public static final String MISC_WISP_LARGE = PREFIX_MISC + "wisp_large.png";
	public static final String MISC_WISP_SMALL = PREFIX_MISC + "wisp_small.png";
	public static final String MISC_HALO = PREFIX_MISC + "halo.png";
	public static final String MISC_GLOW_GREEN = PREFIX_MISC + "glow0.png";
	public static final String MISC_GLOW_CYAN = PREFIX_MISC + "glow1.png";
	public static final String MISC_BABYLON = PREFIX_MISC + "babylon.png";
	public static final String MISC_SKYBOX = PREFIX_MISC + "skybox.png";
	public static final String MISC_RAINBOW = PREFIX_MISC + "rainbow.png";
	public static final String MISC_PLANET = PREFIX_MISC + "planet";

	public static final String CATEGORY_INDEX = PREFIX_CATEGORIES + "index.png";

	public static final String SHADER_PYLON_GLOW_FRAG = PREFIX_SHADER + "pylon_glow.frag";
	public static final String SHADER_ENCHANTER_RUNE_FRAG = PREFIX_SHADER + "enchanter_rune.frag";
	public static final String SHADER_MANA_POOL_FRAG = PREFIX_SHADER + "mana_pool.frag";
	public static final String SHADER_DOPLLEGANGER_VERT = PREFIX_SHADER + "doppleganger.vert";
	public static final String SHADER_DOPLLEGANGER_FRAG = PREFIX_SHADER + "doppleganger.frag";
	public static final String SHADER_HALO_FRAG = PREFIX_SHADER + "halo.frag";
	public static final String SHADER_DOPLLEGANGER_BAR_FRAG = PREFIX_SHADER + "doppleganger_bar.frag";
	public static final String SHADER_TERRA_PLATE_RUNE_FRAG = PREFIX_SHADER + "terra_plate_rune.frag";
	public static final String SHADER_FILM_GRAIN_FRAG = PREFIX_SHADER + "film_grain.frag";
	public static final String SHADER_GOLD_FRAG = PREFIX_SHADER + "gold.frag";
	public static final String SHADER_CATEGORY_BUTTON_FRAG = PREFIX_SHADER + "category_button.frag";
	public static final String SHADER_ALPHA_FRAG = PREFIX_SHADER + "alpha.frag";
	public static final String SHADER_ALPHA_VERT = PREFIX_SHADER + "alpha.vert";

}

==> Botania-r1.11-373.179-sources.jar: vazkii/botania/client/lib/LibResources.java <==
/**
 * This class was created by <Vazkii>. It's distributed as
 * part of the Botania Mod. Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 *
 * File Created @ [Jan 14, 2014, 5:29:31 PM (GMT)]
 */
package vazkii.botania.client.lib;

import vazkii.botania.common.lib.LibMisc;

public final class LibResources {

	public static final String PREFIX_MOD = LibMisc.MOD_ID + ":";

	public static final String PREFIX_LANG = "/assets/botania/lang/";
	public static final String PREFIX_SHADER = "shader/";

	public static final String PREFIX_GUI = PREFIX_MOD + "textures/gui/";
	public static final String PREFIX_ENTRIES = PREFIX_GUI + "entries/";
	public static final String PREFIX_MODEL = PREFIX_MOD + "textures/model/";
	public static final String PREFIX_MISC = PREFIX_MOD + "textures/misc/";
	public static final String PREFIX_OBJ_MODEL = PREFIX_MOD + "model/";
	public static final String PREFIX_CATEGORIES = PREFIX_GUI + "categories/";

	public static final String EMTPY_TEXTURE = "empty_texture";

	public static final String GUI_MANA_HUD = PREFIX_GUI + "mana_hud.png";
	public static final String GUI_LEXICON = PREFIX_GUI + "lexicon.png";
	public static final String GUI_PAPER = PREFIX_GUI + "paper.png";
	public static final String GUI_CRAFTING_OVERLAY = PREFIX_GUI + "crafting_overlay.png";
	public static final String GUI_MANA_INFUSION_OVERLAY = PREFIX_GUI + "mana_infusion_overlay.png";
	public static final String GUI_PURE_DAISY_OVERLAY = PREFIX_GUI + "pure_daisy_overlay.png";
	public static final String GUI_PETAL_OVERLAY = PREFIX_GUI + "petal_overlay.png";
	public static final String GUI_TERRASTEEL_OVERLAY = PREFIX_GUI + "terrasteel_overlay.png";
	public static final String GUI_ELVEN_TRADE_OVERLAY = PREFIX_GUI + "elven_trade_overlay.png";
	public static final String GUI_SHEDDING_OVERLAY = PREFIX_GUI + "shedding_overlay.png";
	public static final String GUI_MULTIBLOCK_OVERLAY = PREFIX_GUI + "multiblock_overlay.png";
	public static final String GUI_CREATIVE = "botania.png";
	public static final String GUI_TOFF = PREFIX_GUI + "toff.png";
	public static final String GUI_BOSS_BAR = PREFIX_GUI + "boss_bar.png";
	public static final String GUI_POTIONS = PREFIX_GUI + "potions.png";
	public static final String GUI_NEI_BLANK = PREFIX_GUI + "nei_blank.png";
	public static final String GUI_NEI_BREWERY = PREFIX_GUI + "nei_brewery.png";
	public static final String GUI_FLOWER_BAG = PREFIX_GUI + "flower_bag.png";
	public static final String GUI_BAUBLE_BOX = PREFIX_GUI + "bauble_box.png";
	public static final String GUI_HUD_ICONS = PREFIX_GUI + "hud_icons.png";
	public static final String GUI_STENCIL = PREFIX_GUI + "stencil.png";
	public static final String GUI_DOG = PREFIX_GUI + "dog.png";
	public static final String GUI_FLOWEY = PREFIX_GUI + "flowey.png";

	public static final String ENTRY_FLOWERS = PREFIX_ENTRIES + "flowers.png";
	public static final String ENTRY_APOTHECARY = PREFIX_ENTRIES + "apothecary.png";
	public static final String ENTRY_PURE_DAISY = PREFIX_ENTRIES + "pure_daisy.png";
	public static final String ENTRY_SPREADER = PREFIX_ENTRIES + "spreader.png";
	public static final String ENTRY_BAUBLES = PREFIX_ENTRIES + "baubles.png";
	public static final String ENTRY_ELVEN_GARDE = PREFIX_ENTRIES + "elven_garde.png";
	public static final String ENTRY_HYDROANGEAS = PREFIX_ENTRIES + "hydroangeas.png";
	public static final String ENTRY_CRAFT_CRATE = PREFIX_ENTRIES + "craft_crate.png";
	public static final String ENTRY_AZULEJOS = PREFIX_ENTRIES + "azulejos.png";
	public static final String ENTRY_METAMORPHIC_STONES = PREFIX_ENTRIES + "metamorphic_stones.png";
	public static final String ENTRY_BANNERS = PREFIX_ENTRIES + "banners.png";

	public static final String MODEL_SPREADER = PREFIX_MODEL + "spreader_mana.png";
	public static final String MODEL_SPREADER_REDSTONE = PREFIX_MODEL + "spreader_redstone.png";
	public static final String MODEL_SPREADER_DREAMWOOD = PREFIX_MODEL + "spreader_dreamwood.png";
	public static final String MODEL_SPREADER_GAIA = PREFIX_MODEL + "spreader_gaia.png";
	public static final String MODEL_SPREADER_HALLOWEEN = PREFIX_MODEL + "spreader_mana_halloween.png";
	public static final String MODEL_SPREADER_REDSTONE_HALLOWEEN = PREFIX_MODEL + "spreader_redstone_halloween.png";
	public static final String MODEL_SPREADER_DREAMWOOD_HALLOWEEN = PREFIX_MODEL + "spreader_dreamwood_halloween.png";
	public static final String MODEL_SPREADER_GAIA_HALLOWEEN = PREFIX_MODEL + "spreader_gaia_halloween.png";
	public static final String MODEL_PYLON_MANA = PREFIX_MODEL + "pylon_mana.png";
	public static final String MODEL_PYLON_NATURA = PREFIX_MODEL + "pylon_natura.png";
	public static final String MODEL_PYLON_GAIA = PREFIX_MODEL + "pylon_gaia.png";
	public static final String MODEL_LEXICA_DEFAULT = PREFIX_MODEL + "lexicon_default.png";
	public static final String MODEL_LEXICA_ELVEN = PREFIX_MODEL + "lexicon_elven.png";
	public static final String MODEL_MANASTEEL_0 = PREFIX_MODEL + "manasteel_0.png";
	public static final String MODEL_MANASTEEL_1 = PREFIX_MODEL + "manasteel_1.png";
	public static final String MODEL_MANASTEEL_2 = PREFIX_MODEL + "manasteel_2.png";
	public static final String MODEL_MANASTEEL_NEW = PREFIX_MODEL + "armor_manasteel.png";
	public static final String MODEL_TERRASTEEL_0 = PREFIX_MODEL + "terrasteel_0.png";
	public static final String MODEL_TERRASTEEL_1 = PREFIX_MODEL + "terrasteel_1.png";
	public static final String MODEL_TERRASTEEL_2 = PREFIX_MODEL + "terrasteel_2.png";
	public static final String MODEL_TERRASTEEL_NEW = PREFIX_MODEL + "armor_terrasteel.png";
	public static final String MODEL_ELEMENTIUM_0 = PREFIX_MODEL + "elementium_0.png";
	public static final String MODEL_ELEMENTIUM_1 = PREFIX_MODEL + "elementium_1.png";
	public static final String MODEL_ELEMENTIUM_2 = PREFIX_MODEL + "elementium_2.png";
	public static final String MODEL_ELEMENTIUM_NEW = PREFIX_MODEL + "armor_elementium.png";
	public static final String MODEL_MANAWEAVE_0 = PREFIX_MODEL + "manaweave_0.png";
	public static final String MODEL_MANAWEAVE_1 = PREFIX_MODEL + "manaweave_1.png";
	public static final String MODEL_MANAWEAVE_NEW = PREFIX_MODEL + "armor_manaweave.png";
	public static final String MODEL_MANAWEAVE_NEW_HOLIDAY = PREFIX_MODEL + "armor_manaweave_holiday.png";
	public static final String MODEL_PIXIE = PREFIX_MODEL + "pixie.png";
	public static final String MODEL_PIXIE_HALLOWEEN = PREFIX_MODEL + "pixie_halloween.png";
	public static final String MODEL_TINY_POTATO = PREFIX_MODEL + "tiny_potato.png";
	public static final String MODEL_TINY_POTATO_GS = PREFIX_MODEL + "tiny_potato_gray.png";
	public static final String MODEL_TINY_POTATO_HALLOWEEN = PREFIX_MODEL + "tiny_potato_halloween.png";
	public static final String MODEL_TRAVEL_BELT = PREFIX_MODEL + "belt_travel.png";
	public static final String MODEL_SUPER_TRAVEL_BELT = PREFIX_MODEL + "belt_travel_super.png";
	public static final String MODEL_SPEED_UP_BELT = PREFIX_MODEL + "belt_speed.png";
	public static final String MODEL_KNOCKBACK_BELT = PREFIX_MODEL + "belt_knockback.png";
	public static final String MODEL_HOLY_CLOAK = PREFIX_MODEL + "cloak_holy.png";
	public static final String MODEL_UNHOLY_CLOAK = PREFIX_MODEL + "cloak_unholy.png";
	public static final String MODEL_BALANCE_CLOAK = PREFIX_MODEL + "cloak_balance.png";
	public static final String MODEL_HOLY_CLOAK_GLOW = PREFIX_MODEL + "cloak_holy_glow.png";
	public static final String MODEL_UNHOLY_CLOAK_GLOW = PREFIX_MODEL + "cloak_unholy_glow.png";
	public static final String MODEL_BALANCE_CLOAK_GLOW = PREFIX_MODEL + "cloak_balance_glow.png";
	public static final String MODEL_CORPOREA_INDEX = PREFIX_MODEL + "corporea_index.png";
	public static final String MODEL_INVISIBLE_ARMOR = PREFIX_MODEL + "armor_invisible.png";
	public static final String MODEL_PINK_WITHER = PREFIX_MODEL + "wither_pink.png";
	public static final String MODEL_BREWERY = PREFIX_MODEL + "brewery.png";
	public static final String MODEL_HOURGLASS = PREFIX_MODEL + "hourglass.png";
	public static final String MODEL_BELLOWS = PREFIX_MODEL + "bellows.png";
	public static final String MODEL_TERU_TERU_BOZU = PREFIX_MODEL + "teru_teru_bozu.png";
	public static final String MODEL_TERU_TERU_BOZU_HALLOWEEN = PREFIX_MODEL + "teru_teru_bozu_halloween.png";
	public static final String MODEL_AVATAR = PREFIX_MODEL + "avatar.png";
	public static final String MODEL_AVATAR_DIVINING = PREFIX_MODEL + "avatar_divining.png";
	public static final String MODEL_AVATAR_FIRE = PREFIX_MODEL + "avatar_fire.png";
	public static final String MODEL_AVATAR_MISSILE = PREFIX_MODEL + "avatar_missile.png";
	public static final String MODEL_AVATAR_RAINBOW = PREFIX_MODEL + "avatar_rainbow.png";
	public static final String MODEL_AVATAR_TORNADO = PREFIX_MODEL + "avatar_tornado.png";
	public static final String MODEL_AVATAR_DIRT = PREFIX_MODEL + "avatar_dirt.png";

	public static final String MISC_PARTICLES = PREFIX_MISC + "particles.png";
	public static final String MISC_WISP_LARGE = PREFIX_MISC + "wisp_large.png";
	public static final String MISC_WISP_SMALL = PREFIX_MISC + "wisp_small.png";
	public static final String MISC_HALO = PREFIX_MISC + "halo.png";
	public static final String MISC_GLOW_GREEN = PREFIX_MISC + "glow0.png";
	public static final String MISC_GLOW_CYAN = PREFIX_MISC + "glow1.png";
	public static final String MISC_BABYLON = PREFIX_MISC + "babylon.png";
	public static final String MISC_SKYBOX = PREFIX_MISC + "skybox.png";
	public static final String MISC_RAINBOW = PREFIX_MISC + "rainbow.png";
	public static final String MISC_PLANET = PREFIX_MISC + "planet";

	public static final String CATEGORY_INDEX = PREFIX_CATEGORIES + "index.png";

	public static final String SHADER_PYLON_GLOW_FRAG = PREFIX_SHADER + "pylon_glow.frag";
	public static final String SHADER_ENCHANTER_RUNE_FRAG = PREFIX_SHADER + "enchanter_rune.frag";
	public static final String SHADER_MANA_POOL_FRAG = PREFIX_SHADER + "mana_pool.frag";
	public static final String SHADER_DOPLLEGANGER_VERT = PREFIX_SHADER + "doppleganger.vert";
	public static final String SHADER_DOPLLEGANGER_FRAG = PREFIX_SHADER + "doppleganger.frag";
	public static final String SHADER_HALO_FRAG = PREFIX_SHADER + "halo.frag";
	public static final String SHADER_DOPLLEGANGER_BAR_FRAG = PREFIX_SHADER + "doppleganger_bar.frag";
	public static final String SHADER_TERRA_PLATE_RUNE_FRAG = PREFIX_SHADER + "terra_plate_rune.frag";
	public static final String SHADER_FILM_GRAIN_FRAG = PREFIX_SHADER + "film_grain.frag";
	public static final String SHADER_GOLD_FRAG = PREFIX_SHADER + "gold.frag";
	public static final String SHADER_CATEGORY_BUTTON_FRAG = PREFIX_SHADER + "category_button.frag";
	public static final String SHADER_ALPHA_FRAG = PREFIX_SHADER + "alpha.frag";
	public static final String SHADER_ALPHA_VERT = PREFIX_SHADER + "alpha.vert";

}
